<?php
/*
 * Set up the content width value based on the theme's design.
 */
if (!function_exists('iPartySetup')) :
    function iPartySetup() {
        global $content_width;
        if (!isset($content_width)) {
            $content_width = 870;
        }
        // Make iParty theme available for translation.
        load_theme_textdomain('iparty', get_template_directory() . '/languages');


        // Add RSS feed links to <head> for posts and comments.
        add_theme_support('automatic-feed-links');

        // register menu 
        register_nav_menus(array(
            'primary' => __('Top Menu', 'iparty'),
            'footer' => __('Footer Menu', 'iparty'),
        ));

        // Featured image support
        add_theme_support('post-thumbnails');
        add_theme_support( 'custom-logo', array(
            'height'      => 80,
            'width'       => 510,
            'flex-height' => true,
            'header-text' => array( 'site-description' ), 
        ) );
        add_image_size('iPartyThumbnailImage', 780, 400, true);
        add_image_size('iPartyBlogThumbnailImage', 1540, 390, true);
        // Switch default core markup for search form, comment form, and commen, to output valid HTML5.
        add_theme_support('html5', array('comment-list'));
        add_theme_support( "custom-background",array('default-color' => '#ffffff'));
        // Add support for featured content.
        add_theme_support('featured-content', array(
            'featured_content_filter' => 'iPartyGetFeaturedPosts',
            'max_posts' => 6,
        ));

        /* slug setup */
        add_theme_support('title-tag');
    }
endif;
add_action('after_setup_theme', 'iPartySetup');

function iPartySpecialNavClass($classes, $item){
     if( in_array('current-menu-item', $classes) ){
             $classes[] = 'active ';
     }
     return $classes;
}

function iPartyExcerptLegnth( $length ) {
    if ( is_admin() ) {
        return $length;
    } 
    return 15;
}
add_filter( 'excerpt_length', 'iPartyExcerptLegnth', 999 );

//clearfix
function iPartyBootstrapClearfix( $iPartyI, $iPartyArgs = array(), $iPartyElement = 'div',  $iPartyGrid = 12 ) {
    $iPartyPerformFor = array();
    $iPartyClearfix   = '';

    if ( isset( $iPartyArgs['xs'] ) && is_int( $iPartyArgs['xs'] ) ) {
        $iPartyPerformFor[] = 'xs';
    }
    if ( isset( $iPartyArgs['sm'] ) && is_int( $iPartyArgs['sm'] ) ) {
        $iPartyPerformFor[] = 'sm';
    }
    if ( isset( $iPartyArgs['md'] ) && is_int( $iPartyArgs['md'] ) ) {
        $iPartyPerformFor[] = 'md';
    }
    if ( isset( $iPartyArgs['lg'] ) && is_int( $iPartyArgs['lg'] ) ) {
        $iPartyPerformFor[] = 'lg';
    }

    foreach ( $iPartyPerformFor as $iPartyV ) {
        $iPartyModulus = $iPartyGrid / $iPartyArgs[ $iPartyV ];
        $iPartyClearfix .= ( $iPartyI > 0 && $iPartyI % $iPartyModulus == 0 ? ' <'.$iPartyElement.' class="clearfix visible-' . $iPartyV . '"></'.$iPartyElement.'>' : '' );
    }
    return $iPartyClearfix;
}

function iPartyColourBrightness($iPartyHex, $iPartyPercent) {
    // Work out if hash given
    $iPartyHash = '';
    if (stristr($iPartyHex,'#')) {
        $iPartyHex = str_replace('#','',$iPartyHex);
        $iPartyHash = '#';
    }
    /// HEX TO RGB
    $iPartyRgb = array(hexdec(substr($iPartyHex,0,2)), hexdec(substr($iPartyHex,2,2)), hexdec(substr($iPartyHex,4,2)));
    //// CALCULATE 
    for ($iPartyI=0; $iPartyI<3; $iPartyI++) {
        // See if brighter or darker
        if ($iPartyPercent > 0) {
            // Lighter
            $iPartyRgb[$iPartyI] = round($iPartyRgb[$iPartyI] * $iPartyPercent) + round(255 * (1-$iPartyPercent));
        } else {
            // Darker
            $iPartyPositivePercent = $iPartyPercent - ($iPartyPercent*2);
            $iPartyRgb[$iPartyI] = round($iPartyRgb[$iPartyI] * $iPartyPositivePercent) + round(0 * (1-$iPartyPositivePercent));
        }
        // In case rounding up causes us to go to 256
        if ($iPartyRgb[$iPartyI] > 255) {
            $iPartyRgb[$iPartyI] = 255;
        }
    }
    //// RBG to Hex
    $iPartyHex = '';
    for($iPartyI=0; $iPartyI < 3; $iPartyI++) {
        // Convert the decimal digit to hex
        $iPartyHexDigit = dechex($iPartyRgb[$iPartyI]);
        // Add a leading zero if necessary
        if(strlen($iPartyHexDigit) == 1) {
            $iPartyHexDigit = "0" . $iPartyHexDigit;
        }
        // Append to the hex string
        $iPartyHex .= $iPartyHexDigit;
    }
    return $iPartyHash.$iPartyHex;
}
function ipartyMenuSettings() {
    $ipartyMenu = array(
    );
}

add_action('admin_menu', 'ipartyOptionsAddPage');

//Documentation Menu Link
add_action('admin_menu', 'ipartyOptionsAddPage');
function ipartyOptionsAddPage() {
  add_theme_page(__('iPartyPro Features', 'iparty'), __('iPartyPro Features', 'iparty'), 'edit_theme_options', 'iparty','ipartypro_page');
  add_theme_page( 'iParty Documentation', 'iParty Documentation', 'manage_options', 'iparty-documentation', 'ipartyDocumentation', 400 );
}

function ipartypro_page(){ ?>
<div class="">
  <a href="<?php echo esc_url('https://indigothemes.com/products/iparty-pro-wordpress-theme/'); ?>" target="_blank">
    <img src ="<?php echo esc_url('https://indigothemes.com/wp-content/uploads/iParty/pro-features.jpg') ?>" width="100%" height="auto" />
  </a>
</div>

<?php
}
function ipartyDocumentation(){ ?>
  <script>
    window.location = "https://indigothemes.com/documentation/iparty";
  </script>
<?php 
                               }
/** * Enqueue css and js files **/
require get_template_directory() . '/functions/theme-default-setup.php';
require get_template_directory() . '/functions/enqueue-files.php';
require get_template_directory() . '/functions/theme-customization.php';
require_once get_template_directory() . '/functions/class-tgm-plugin-activation.php';
/*
* TGM plugin activation register hook 
*/
add_action( 'tgmpa_register', 'ipartyActionTgmPluginActiveRegisterRequiredPlugins' );
function ipartyActionTgmPluginActiveRegisterRequiredPlugins() {
    if(class_exists('TGM_Plugin_Activation')){
      $plugins = array(
        array(
           'name'      => __('Page Builder by SiteOrigin','iparty'),
           'slug'      => 'siteorigin-panels',
           'required'  => true,
        ),
        array(
           'name'      => __('SiteOrigin Widgets Bundle','iparty'),
           'slug'      => 'so-widgets-bundle',
           'required'  => true,
        ),
        array(
           'name'      => __('Contact Form 7','iparty'),
           'slug'      => 'contact-form-7',
           'required'  => true,
        ),       
      );
      $config = array(
        'default_path' => '',
        'menu'         => 'iparty-install-plugins',
        'has_notices'  => true,
        'dismissable'  => true,
        'dismiss_msg'  => '',
        'is_automatic' => false,
        'message'      => '',
        'strings'      => array(
         'page_title'                      => __( 'Install Required Plugins', 'iparty' ),
         'menu_title'                      => __( 'Install Plugins', 'iparty' ),
         'installing'                      => __( 'Installing Plugin: %s', 'iparty' ), 
         'oops'                            => __( 'Something went wrong with the plugin API.', 'iparty' ),
         'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.','iparty' ), 
         'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.','iparty' ), 
         'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','iparty' ), 
         'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','iparty' ), 
         'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','iparty' ), 
         'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','iparty' ), 
         'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','iparty' ), 
         'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','iparty' ), 
         'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins','iparty' ),
         'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins','iparty' ),
         'return'                          => __( 'Return to Required Plugins Installer', 'iparty' ),
         'plugin_activated'                => __( 'Plugin activated successfully.', 'iparty' ),
         'complete'                        => __( 'All plugins installed and activated successfully. %s', 'iparty' ), 
         'nag_type'                        => 'updated'
        )
      );
      iparty( $plugins, $config );
    }
}
function iparty_add_widget_folders( $folders ){
    $folders[] = get_template_directory() . '/functions/widgets/';
    return $folders;
}
add_action('siteorigin_widgets_widget_folders', 'iparty_add_widget_folders');
?>